@@ -6,3 +6,6 @@ DEFAULT_URL_PREFIX = '/autorest'
 DEFAULT_PER_PAGE = 1000
 # -1 代表不限制
 DEFAULT_MAX_PER_PAGE = -1
+
+# 是否自动创建不存在的表，添加不存在的列
+DEFAULT_AUTO_FIX_TABLE = True
